==> haskell-tasty-quickcheck-0.10.1.1-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-quickcheck
version:              0.10.1.1
visibility:           public
id:                   tasty-quickcheck-0.10.1.1-HjrFDfWXFN6GFS4mKKPCnG
key:                  tasty-quickcheck-0.10.1.1-HjrFDfWXFN6GFS4mKKPCnG
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/tasty
synopsis:             QuickCheck support for the Tasty test framework.
description:          QuickCheck support for the Tasty test framework.
category:             Testing
abi:                  5b6c9a93b0aef6d0da54091a2031ec9c
exposed:              True
exposed-modules:      Test.Tasty.QuickCheck
import-dirs:          /usr/lib/ghc-8.10.2/site-local/tasty-quickcheck-0.10.1.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/tasty-quickcheck-0.10.1.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/tasty-quickcheck-0.10.1.1

hs-libraries:         HStasty-quickcheck-0.10.1.1-HjrFDfWXFN6GFS4mKKPCnG
depends:
    QuickCheck-2.14.1-9QGOOtk2Q9p4Zfm3TyYrdl base-4.14.1.0
    optparse-applicative-0.15.1.0-1tT6bgsk4hf9ZtV24lmm9i
    random-1.2.0-8IftmqPK4uI6mV4relajfT
    tagged-0.8.6-6ynGuqiqWewDmeFAuVgKQe
    tasty-1.3.1-D5FQrcyNRZnGDV2JzpPufq

haddock-interfaces:
    /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-quickcheck-0.10.1.1-68-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-quickcheck
version:              0.10.1.1
visibility:           public
id:                   tasty-quickcheck-0.10.1.1-Jab1ByEybny3z30pUPj6lp
key:                  tasty-quickcheck-0.10.1.1-Jab1ByEybny3z30pUPj6lp
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/tasty
synopsis:             QuickCheck support for the Tasty test framework.
description:          QuickCheck support for the Tasty test framework.
category:             Testing
abi:                  7bc8535e06649383c50d0b65ecf410ce
exposed:              True
exposed-modules:      Test.Tasty.QuickCheck
import-dirs:          /usr/lib/ghc-8.10.2/site-local/tasty-quickcheck-0.10.1.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/tasty-quickcheck-0.10.1.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/tasty-quickcheck-0.10.1.1

hs-libraries:         HStasty-quickcheck-0.10.1.1-Jab1ByEybny3z30pUPj6lp
depends:
    QuickCheck-2.14.1-ImMnmQnYyzf4BNCbXbRnTg base-4.14.1.0
    optparse-applicative-0.15.1.0-EGSqvGNokMX25ehE0zny79
    random-1.2.0-1XErNwNJzZZFg41vgbJp5j
    tagged-0.8.6-6ynGuqiqWewDmeFAuVgKQe
    tasty-1.3.1-3R4DOsioELF2UCXZMw8UL4

haddock-interfaces:
    /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
